@@ -14,7 +14,7 @@ import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
 
-from metpy.calc import dewpoint_rh
+from metpy.calc import dewpoint_from_relative_humidity
 from metpy.cbook import get_test_data
 from metpy.plots import add_metpy_logo
 from metpy.units import units
@@ -25,7 +25,7 @@ def calc_mslp(t, p, h):
 
 
 # Make meteogram plot
-class Meteogram(object):
+class Meteogram:
     """ Plot a time series of meteorological data from a particular station as a
     meteogram with standard variables to visualize, including thermodynamic,
     kinematic, and pressure. The functions below control the plotting of each
@@ -51,7 +51,7 @@ class Meteogram(object):
         self.axis_num = 0
         self.dates = mpl.dates.date2num(dates)
         self.time = time.strftime('%Y-%m-%d %H:%M UTC')
-        self.title = 'Latest Ob Time: {0}\nProbe ID: {1}'.format(self.time, probeid)
+        self.title = f'Latest Ob Time: {self.time}\nProbe ID: {probeid}'
 
     def plot_winds(self, ws, wd, wsmax, plot_range=None):
         """
@@ -79,7 +79,8 @@ class Meteogram(object):
         ln3 = ax7.plot(self.dates, wd, '.k', linewidth=0.5, label='Wind Direction')
         ax7.set_ylabel('Wind\nDirection\n(degrees)', multialignment='center')
         ax7.set_ylim(0, 360)
-        ax7.set_yticks(np.arange(45, 405, 90), ['NE', 'SE', 'SW', 'NW'])
+        ax7.set_yticks(np.arange(45, 405, 90))
+        ax7.set_yticklabels(['NE', 'SE', 'SW', 'NW'])
         lines = ln1 + ln2 + ln3
         labs = [line.get_label() for line in lines]
         ax7.xaxis.set_major_formatter(mpl.dates.DateFormatter('%d/%H UTC'))
@@ -201,8 +202,8 @@ probe_id = '0102A'
 data = {'wind_speed': (np.array(ws) * units('m/s')).to(units('knots')),
         'wind_speed_max': (np.array(wsmax) * units('m/s')).to(units('knots')),
         'wind_direction': np.array(wd) * units('degrees'),
-        'dewpoint': dewpoint_rh((np.array(temp) * units('degC')).to(units('K')),
-                                np.array(rh) / 100.).to(units('degF')),
+        'dewpoint': dewpoint_from_relative_humidity((np.array(temp) * units.degC).to(units.K),
+                                                    np.array(rh) / 100.).to(units('degF')),
         'air_temperature': (np.array(temp) * units('degC')).to(units('degF')),
         'mean_slp': calc_mslp(np.array(temp), np.array(pres), hgt_example) * units('hPa'),
         'relative_humidity': np.array(rh), 'times': np.array(date)}
