@@ -32,6 +32,6 @@ warnings.filterwarnings('ignore', 'numpy.dtype size changed')
 os.environ['PINT_ARRAY_PROTOCOL_FALLBACK'] = '0'
 
 from ._version import get_version  # noqa: E402
-from .xarray import *  # noqa: F401, F403
+from .xarray import *  # noqa: F401, F403, E402
 __version__ = get_version()
 del get_version
