@@ -54,7 +54,7 @@ def open_as_needed(filename, mode='rb'):
         return gzip.GzipFile(filename, mode)
     else:
         kwargs = {'errors': 'surrogateescape'} if mode != 'rb' else {}
-        return open(filename, mode, **kwargs)
+        return open(filename, mode, **kwargs)  # noqa: SIM115
 
 
 class NamedStruct(Struct):
