@@ -24,7 +24,7 @@ import re
 import warnings
 
 import numpy as np
-from pyproj import Proj
+from pyproj import CRS, Proj
 import xarray as xr
 
 from ._vendor.xarray import either_dict_or_kwargs, expanded_indexer, is_dict_like
@@ -128,8 +128,8 @@ class MetPyDataArrayAccessor:
     @property
     def units(self):
         """Return the units of this DataArray as a `pint.Unit`."""
-        if isinstance(self._data_array.data, units.Quantity):
-            return self._data_array.data.units
+        if isinstance(self._data_array.variable._data, units.Quantity):
+            return self._data_array.variable._data.units
         else:
             return units.parse_units(self._data_array.attrs.get('units', 'dimensionless'))
 
@@ -444,8 +444,8 @@ class MetPyDataArrayAccessor:
     @property
     def time_deltas(self):
         """Return the time difference of the data in seconds (to microsecond precision)."""
-        return (np.diff(self._data_array.values).astype('timedelta64[us]').astype('int64')
-                / 1e6 * units.s)
+        us_diffs = np.diff(self._data_array.values).astype('timedelta64[us]').astype('int64')
+        return units.Quantity(us_diffs / 1e6, 's')
 
     def find_axis_name(self, axis):
         """Return the name of the axis corresponding to the given identifier.
@@ -747,18 +747,28 @@ class MetPyDatasetAccessor:
             else:
                 crs = CFProjection(proj_var.attrs)
 
-        if crs is None and not check_axis(var, 'latitude', 'longitude'):
+        if crs is None:
             # This isn't a lat or lon coordinate itself, so determine if we need to fall back
-            # to creating a latitude_longitude CRS. We do so if there exists valid coordinates
-            # for latitude and longitude, even if they are not the dimension coordinates of
-            # the variable.
-            def _has_coord(coord_type):
-                return any(check_axis(coord_var, coord_type)
-                           for coord_var in var.coords.values())
-            if _has_coord('latitude') and _has_coord('longitude'):
-                crs = CFProjection({'grid_mapping_name': 'latitude_longitude'})
-                log.warning('Found valid latitude/longitude coordinates, assuming '
-                            'latitude_longitude for projection grid_mapping variable')
+            # to creating a latitude_longitude CRS. We do so if there exists valid *at most
+            # 1D* coordinates for latitude and longitude (usually dimension coordinates, but
+            # that is not strictly required, for example, for DSG's). What is required is that
+            # x == latitude and y == latitude (so that all assumptions about grid coordinates
+            # and CRS line up).
+            try:
+                latitude, y, longitude, x = var.metpy.coordinates(
+                    'latitude',
+                    'y',
+                    'longitude',
+                    'x'
+                )
+            except AttributeError:
+                # This means that we don't even have sufficient coordinates, so skip
+                pass
+            else:
+                if latitude.identical(y) and longitude.identical(x):
+                    crs = CFProjection({'grid_mapping_name': 'latitude_longitude'})
+                    log.warning('Found valid latitude/longitude coordinates, assuming '
+                                'latitude_longitude for projection grid_mapping variable')
 
         # Rebuild the coordinates of the dataarray, and return quantified DataArray
         var = self._rebuild_coords(var, crs)
@@ -780,7 +790,7 @@ class MetPyDatasetAccessor:
                         new_coord_var = coord_var.copy(
                             data=(
                                 coord_var.metpy.unit_array
-                                * (height * units.meter)
+                                * units.Quantity(height, 'meter')
                             ).m_as('meter')
                         )
                         new_coord_var.attrs['units'] = 'meter'
@@ -1355,9 +1365,17 @@ def grid_deltas_from_dataarray(f, kind='default'):
     from metpy.calc import lat_lon_grid_deltas
 
     # Determine behavior
-    if kind == 'default' and f.metpy.crs['grid_mapping_name'] == 'latitude_longitude':
+    if (
+        kind == 'default'
+        and (
+            not hasattr(f.metpy, 'crs')
+            or f.metpy.crs['grid_mapping_name'] == 'latitude_longitude'
+        )
+    ):
+        # Use actual grid deltas by default with latitude_longitude or missing CRS
         kind = 'actual'
     elif kind == 'default':
+        # Otherwise, use grid deltas in projected grid space by default
         kind = 'nominal'
     elif kind not in ('actual', 'nominal'):
         raise ValueError('"kind" argument must be specified as "default", "actual", or '
@@ -1373,11 +1391,17 @@ def grid_deltas_from_dataarray(f, kind='default'):
             warnings.warn('y and x dimensions unable to be identified. Assuming [..., y, x] '
                           'dimension order.')
             y_dim, x_dim = -2, -1
+
+        # Get geod if it exists, otherwise fall back to PyProj default
+        try:
+            geod = f.metpy.pyproj_crs.get_geod()
+        except AttributeError:
+            geod = CRS.from_cf({'grid_mapping_name': 'latitude_longitude'}).get_geod()
         # Obtain grid deltas as xarray Variables
         (dx_var, dx_units), (dy_var, dy_units) = (
             (xr.Variable(dims=latitude.dims, data=deltas.magnitude), deltas.units)
             for deltas in lat_lon_grid_deltas(longitude, latitude, x_dim=x_dim, y_dim=y_dim,
-                                              geod=f.metpy.pyproj_crs.get_geod()))
+                                              geod=geod))
     else:
         # Obtain y/x coordinate differences
         y, x = f.metpy.coordinates('y', 'x')
@@ -1387,10 +1411,12 @@ def grid_deltas_from_dataarray(f, kind='default'):
         dy_units = units(y.attrs.get('units'))
 
     # Broadcast to input and attach units
-    dx = dx_var.set_dims(f.dims, shape=[dx_var.sizes[dim] if dim in dx_var.dims else 1
-                                        for dim in f.dims]).data * dx_units
-    dy = dy_var.set_dims(f.dims, shape=[dy_var.sizes[dim] if dim in dy_var.dims else 1
-                                        for dim in f.dims]).data * dy_units
+    dx_var = dx_var.set_dims(f.dims, shape=[dx_var.sizes[dim] if dim in dx_var.dims else 1
+                                            for dim in f.dims])
+    dx = units.Quantity(dx_var.data, dx_units)
+    dy_var = dy_var.set_dims(f.dims, shape=[dy_var.sizes[dim] if dim in dy_var.dims else 1
+                                            for dim in f.dims])
+    dy = units.Quantity(dy_var.data, dy_units)
 
     return dx, dy
 
