@@ -138,13 +138,13 @@ def thin_point_data():
 
 @pytest.mark.parametrize('radius, truth',
                          [(2.0, np.array([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-                                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=np.bool)),
+                                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=bool)),
                           (1.0, np.array([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-                                          0, 0, 0, 0, 0, 0, 0, 0, 1, 0], dtype=np.bool)),
+                                          0, 0, 0, 0, 0, 0, 0, 0, 1, 0], dtype=bool)),
                           (0.3, np.array([1, 1, 1, 0, 1, 0, 0, 1, 1, 0, 0,
-                                          0, 0, 0, 0, 0, 1, 0, 0, 0, 0], dtype=np.bool)),
+                                          0, 0, 0, 0, 0, 1, 0, 0, 0, 0], dtype=bool)),
                           (0.1, np.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1,
-                                          0, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=np.bool))
+                                          0, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=bool))
                           ])
 def test_reduce_point_density(thin_point_data, radius, truth):
     r"""Test that reduce_point_density works."""
@@ -153,13 +153,13 @@ def test_reduce_point_density(thin_point_data, radius, truth):
 
 @pytest.mark.parametrize('radius, truth',
                          [(2.0, np.array([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-                                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=np.bool)),
+                                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=bool)),
                           (1.0, np.array([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-                                          0, 0, 0, 0, 0, 0, 0, 0, 1, 0], dtype=np.bool)),
+                                          0, 0, 0, 0, 0, 0, 0, 0, 1, 0], dtype=bool)),
                           (0.3, np.array([1, 1, 1, 0, 1, 0, 0, 1, 1, 0, 0,
-                                          0, 0, 0, 0, 0, 1, 0, 0, 0, 0], dtype=np.bool)),
+                                          0, 0, 0, 0, 0, 1, 0, 0, 0, 0], dtype=bool)),
                           (0.1, np.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1,
-                                          0, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=np.bool))
+                                          0, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=bool))
                           ])
 def test_reduce_point_density_units(thin_point_data, radius, truth):
     r"""Test that reduce_point_density works with units."""
@@ -169,13 +169,13 @@ def test_reduce_point_density_units(thin_point_data, radius, truth):
 
 @pytest.mark.parametrize('radius, truth',
                          [(2.0, np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-                                          0, 0, 0, 0, 0, 0, 0, 0, 0, 1], dtype=np.bool)),
+                                          0, 0, 0, 0, 0, 0, 0, 0, 0, 1], dtype=bool)),
                           (0.7, np.array([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-                                          0, 0, 0, 1, 0, 0, 0, 0, 0, 1], dtype=np.bool)),
+                                          0, 0, 0, 1, 0, 0, 0, 0, 0, 1], dtype=bool)),
                           (0.3, np.array([1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 0,
-                                          0, 0, 0, 1, 0, 0, 0, 1, 0, 1], dtype=np.bool)),
+                                          0, 0, 0, 1, 0, 0, 0, 1, 0, 1], dtype=bool)),
                           (0.1, np.array([1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1,
-                                          0, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=np.bool))
+                                          0, 1, 1, 1, 1, 1, 1, 1, 1, 1], dtype=bool))
                           ])
 def test_reduce_point_density_priority(thin_point_data, radius, truth):
     r"""Test that reduce_point_density works properly with priority."""
@@ -187,7 +187,7 @@ def test_reduce_point_density_1d():
     r"""Test that reduce_point_density works with 1D points."""
     x = np.array([1, 3, 4, 8, 9, 10])
     assert_array_equal(reduce_point_density(x, 2.5),
-                       np.array([1, 0, 1, 1, 0, 0], dtype=np.bool))
+                       np.array([1, 0, 1, 1, 0, 0], dtype=bool))
 
 
 def test_delete_masked_points():
@@ -358,6 +358,17 @@ def test_get_layer(pressure, variable, heights, bottom, depth, interp, expected)
     assert_array_almost_equal(y_layer, expected[1], 3)
 
 
+def test_get_layer_masked():
+    """Test get_layer with masked arrays as input."""
+    p = units.Quantity(np.ma.array([1000, 500, 400]), 'hPa')
+    u = units.Quantity(np.arange(3), 'm/s')
+    p_layer, u_layer = get_layer(p, u, depth=units.Quantity(6000, 'm'))
+    true_p_layer = units.Quantity([1000., 500., 464.4742], 'hPa')
+    true_u_layer = units.Quantity([0., 1., 1.3303], 'm/s')
+    assert_array_almost_equal(p_layer, true_p_layer, 4)
+    assert_array_almost_equal(u_layer, true_u_layer, 4)
+
+
 def test_greater_or_close():
     """Test floating point greater or close to."""
     x = np.array([0.0, 1.0, 1.49999, 1.5, 1.5000, 1.7])
