@@ -3,6 +3,7 @@
 # SPDX-License-Identifier: BSD-3-Clause
 """Test the operation of MetPy's XArray accessors."""
 from collections import OrderedDict
+from unittest.mock import patch, PropertyMock
 
 import numpy as np
 import pyproj
@@ -115,6 +116,13 @@ def test_units(test_var):
     assert test_var.metpy.units == units.kelvin
 
 
+def test_units_data(test_var):
+    """Test units property fetching does not touch variable.data."""
+    with patch.object(xr.Variable, 'data', new_callable=PropertyMock) as mock_data_property:
+        test_var.metpy.units
+        mock_data_property.assert_not_called()
+
+
 def test_units_percent():
     """Test that '%' is handled as 'percent'."""
     test_var_percent = xr.open_dataset(
@@ -220,8 +228,8 @@ def test_radian_projection_coords():
     assert data_var.coords['y'].metpy.unit_array[1] == 3 * units.meter
 
 
-def test_missing_grid_mapping():
-    """Test falling back to implicit lat/lon projection."""
+def test_missing_grid_mapping_valid():
+    """Test falling back to implicit lat/lon projection when valid."""
     lon = xr.DataArray(-np.arange(3),
                        attrs={'standard_name': 'longitude', 'units': 'degrees_east'})
     lat = xr.DataArray(np.arange(2),
@@ -230,7 +238,16 @@ def test_missing_grid_mapping():
     ds = xr.Dataset({'data': data})
 
     data_var = ds.metpy.parse_cf('data')
-    assert 'metpy_crs' in data_var.coords
+    assert (
+        'metpy_crs' in data_var.coords
+        and data_var.metpy.crs['grid_mapping_name'] == 'latitude_longitude'
+    )
+
+
+def test_missing_grid_mapping_invalid(test_var_multidim_no_xy):
+    """Test not falling back to implicit lat/lon projection when invalid."""
+    data_var = test_var_multidim_no_xy.to_dataset(name='data').metpy.parse_cf('data')
+    assert 'metpy_crs' not in data_var.coords
 
 
 def test_missing_grid_mapping_var(caplog):
@@ -367,12 +384,12 @@ def test_resolve_axis_conflict_double_lonlat(test_ds_generic):
     test_ds_generic['d'].attrs['_CoordinateAxisType'] = 'Lat'
     test_ds_generic['e'].attrs['_CoordinateAxisType'] = 'Lon'
 
-    with pytest.warns(UserWarning, match='More than one x coordinate'):
-        with pytest.raises(AttributeError):
-            test_ds_generic['test'].metpy.x
-    with pytest.warns(UserWarning, match='More than one y coordinate'):
-        with pytest.raises(AttributeError):
-            test_ds_generic['test'].metpy.y
+    with pytest.warns(UserWarning, match='More than one x coordinate'),\
+            pytest.raises(AttributeError):
+        test_ds_generic['test'].metpy.x
+    with pytest.warns(UserWarning, match='More than one y coordinate'),\
+            pytest.raises(AttributeError):
+        test_ds_generic['test'].metpy.y
 
 
 def test_resolve_axis_conflict_double_xy(test_ds_generic):
@@ -382,12 +399,12 @@ def test_resolve_axis_conflict_double_xy(test_ds_generic):
     test_ds_generic['d'].attrs['standard_name'] = 'projection_x_coordinate'
     test_ds_generic['e'].attrs['standard_name'] = 'projection_y_coordinate'
 
-    with pytest.warns(UserWarning, match='More than one x coordinate'):
-        with pytest.raises(AttributeError):
-            test_ds_generic['test'].metpy.x
-    with pytest.warns(UserWarning, match='More than one y coordinate'):
-        with pytest.raises(AttributeError):
-            test_ds_generic['test'].metpy.y
+    with pytest.warns(UserWarning, match='More than one x coordinate'),\
+            pytest.raises(AttributeError):
+        test_ds_generic['test'].metpy.x
+    with pytest.warns(UserWarning, match='More than one y coordinate'),\
+            pytest.raises(AttributeError):
+        test_ds_generic['test'].metpy.y
 
 
 def test_resolve_axis_conflict_double_x_with_single_dim(test_ds_generic):
@@ -404,9 +421,9 @@ def test_resolve_axis_conflict_double_vertical(test_ds_generic):
     test_ds_generic['b'].attrs['units'] = 'hPa'
     test_ds_generic['c'].attrs['units'] = 'Pa'
 
-    with pytest.warns(UserWarning, match='More than one vertical coordinate'):
-        with pytest.raises(AttributeError):
-            test_ds_generic['test'].metpy.vertical
+    with pytest.warns(UserWarning, match='More than one vertical coordinate'),\
+            pytest.raises(AttributeError):
+        test_ds_generic['test'].metpy.vertical
 
 
 criterion_matches = [
